import setuptools

# with open("README.md", "r") as fh:
#     long_description = fh.read()

setuptools.setup(
    name="emjolnir", # Replace with your own username
    version="0.0.5",
    author="pyotel",
    author_email="pyotel@gmail.com",
    description="A small example package",
    long_description="long_description",
    long_description_content_type="text/markdown",
    url="https://github.com/pyotel/emjolnir",
    packages=['emjolnir'],
    scripts=['emjolnir/wt_field.dat'],
#    package_data = {'': ['emjolnir/wt_field.dat']},
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)


#from emjolnir import mjolnir
from emjolnir.mjolnir import *
import random

class gwangjin_wt_dataloader(wt_dataloader) :
    def load_data(self):
        #TODO: Users need to populate list_dict_data according to their data storage system.
        for list_number in range(0,50) :
            line_dict = dict()
            for key_str in self.list_field :
                line_dict[key_str] = random.randrange(10**10,10**10*9)
            self.list_dict_data.append(line_dict)    

if __name__ == '__main__':
    inst_wt_data = gwangjin_wt_dataloader("gwangjin", mqtt_ip="test.mosquitto.org", mqtt_port=1883)
    inst_wt_data.run_service()


from abc import *
import os
import paho.mqtt.client as mqtt

class re_dataloader(metaclass=ABCMeta) :
    
    @abstractmethod
    def __init__(self, name, mqtt_ip, mqtt_port):
        self.re_type = "none"
        self.list_field = list()
        self.list_dict_data = list()    
        self.cur_path = os.path.dirname(os.path.abspath(__file__))
        self.mqtt_ip = mqtt_ip
        self.mqtt_port = mqtt_port
    
    @abstractmethod
    def load_data(self):
        pass
    
    def check_field(self):
        print(self.list_dict_data)
    
    def run_service(self):
        self.load_data()
        self.check_field()
        def on_connect(client, userdata, flags, rc):
            print("Connected with result code : "+str(rc))
            client.subscribe("mqtt/"+ self.name +"/#")

        def on_message(client, userdata, msg):
            print(msg.topic+" "+str(msg.payload))

        client = mqtt.Client()
        client.on_connect = on_connect
        client.on_message = on_message

        client.connect(self.mqtt_ip, self.mqtt_port, 60)

        client.loop_forever()

class wt_dataloader(re_dataloader) :
    
    def __init__(self, name, mqtt_ip, mqtt_port):
        super().__init__(self, mqtt_ip, mqtt_port)
        self.re_type = "wt"
        self.name = name
        f = open(self.cur_path + '/wt_field.dat','r')
        lines = f.readlines()
        for line in lines:
            self.list_field.append(line.strip())
        f.close()